/*******************************************************************************
 * JMMC project ( http://www.jmmc.fr ) - Copyright (C) CNRS.
 ******************************************************************************/

/*
 * Yorick plugin for AMBER Data Reduction Software
 */

// cfitsio plugin
#include "cfitsioPlugin.i"

// LAOG - Yorick contribution packages
#include "yoco.i"
#include "yocoPlugin.i"
#include "oiFitsUtils.i"

// Plugins
#include "amdlibCalibrate.i"
#include "amdlibPlugin.i"

#include "amdlibFile.i"
#include "amdlibUV.i"
#include "amdlibRawData.i"
#include "amdlibP2VM.i"
#include "amdlibOiData.i"
#include "amdlibOiStructures.i"
#include "amdlibGraphics.i"
#include "amdlibDataQuality.i"
#include "amdlibBadPixels.i"
#include "amdlibFlatField.i"
#include "amdlibBrowser.i"
#include "amdlibPreferences.i"

func amdlib(void)
/* DOCUMENT amdlib(void)

  DESCRIPTION
    Main Yorick functions related to amdlib plugin

  REQUIRE
    
  CAUTIONS

  AUTHORS (in alphabetic order)
    - Evelyne Altariba 
    - Alain Chelli
    - Gilles Duvert 
    - Laurence Gluck
    - Oscar Hernandez 
    - Jean-Baptiste Le Bouquin 
    - Fabien Malbet 
    - Florentin Millour 
    - Eric Tatulli 
    - Gerard Zins 

  CONTRIBUTIONS
    If you want to contribute with any new file related function, just append it
    to the end of file, and add it to the following function list.

  USEFUL FUNCTIONS
    - amdlibCreateLog                : Generates a log file describing files
                                       data type in directory
    - amdlibShowRawData              : Loads and display raw data file
    - amdlibLoadRawData              : Loads raw data file.
    - amdlibComputeP2vm              : Computes a P2VM
    - amdlibComputeAllP2vm           : Computes all P2VM in directory
    - amdlibShowP2vm                 : Shows a P2VM
    - amdlibLoadP2vm                 : Loads a P2VM
    - amdlibComputeOiData            : Computes interferometric observables
    - amdlibComputeAllOiData         : Computes all interferometric
                                       observables in directory
    - amdlibShowOiData               : Shows OI-FITS file
    - amdlibLoadOiData               : Loads a OI-FITS file
    - amdlibPerformFrameSelection    : Performs a frame selection on OI-FITS
                                       file
    - amdlibPerformAllFrameSelection : Performs all frame selection on OI-FITS
                                       files located in a given directory
    - amdlibLoadFrameSelection       : Loads file resulting from selection
    - amdlibSaveFrameSelection       : Creates a selection file
    - amdlibAppendOiData             : Produce a big merged file (with all the
                                       frames) from a series of OI data files
    - amdlibAppendAllOiData          : Append all OI data files of a directory
                                       in a 'cleaver' way  - NOT YET VALIDATED
    - amdlibShowBadPixelMap          : Displays the bad pixel map currently used
    - amdlibLoadBadPixelMap          : Loads a bad pixel map from file
    - amdlibIsBadPixelMapLoaded      : Checks whether bad pixel map has been
                                       loaded or not
    - amdlibShowFlatFieldMap         : Displays the flat field map currently
                                       used 
    - amdlibLoadFlatFieldMap         : Loads a flat field map from file
    - amdlibIsFlatFieldMapLoaded     : Checks whether flat field map has been
                                       loaded or not
    - amdlibSetPreference            : Set an application preference.
    - amdlibGetPreference            : Get an application preference.
    - amdlibShowPreferences          : Show application preferences.

    
    - amdlibDivideOiData             : Calibrate by a calibrator - NOT YET 
                                       VALIDATED
    - amdlibCheckSpectralShift       : Check spectral shift - NOT YET VALIDATED
    
  For any question, send an email to the amber data reduction mailing list :
      jmmc-amb-datared@ujf-grenoble.fr
  or to the user support :
      jmmc-user-support@ujf-grenoble.fr 
*/
{
    amdlibVersion, version;
    if (am_subroutine())
    {
        yocoLogInfo, "AMBER Data Reduction Software -" +  version + "\n";
        help, amdlib;
    }   
    return version;
}

